from distutils.core import setup
setup(
    name='fritzcontrol',
    packages=['fritzcontrol'],  # this must be the same as the name above
    version='1.0.1',
    description='Library to control your FritzBox',
    author='Tom Jaster',
    author_email='futur3.tom@googlemail.com',
    url='https://github.com/Harper04/python-fritzbox-control',  # use the URL to the github repo
    download_url='https://github.com/Harper04/python-fritzbox-control/tarball/1.0',
    keywords=['fritzbox', 'remote', 'control'],  # arbitrary keywords
    classifiers=[],
)
